﻿using System;

//// This is where code contracts are defined.
using System.Diagnostics.Contracts;

//// This namespace is defined in the CelestialUnits.dll library.
//// It already contains definitions for CelestialPoint, RightAscension,
//// and declination. Also, the entire ICRF2 database is in the
//// static array ICRF2.Points.
using CelestialUnits;

namespace NavLib
{ 
    /// <summary>
    /// This is the class that implements your navigation system.
    /// The class must be called Navigator for the simulator to find it.
    /// Also the Navigator class must have a constructor without any arguments,
    /// and must have the two methods below. The simulator constructs only one
    /// instance of this class and repeatedly calls the Locate methods.
    /// </summary>
    public class Navigator
    {

        /// <summary>
        /// Type "locate" from the simulator to call this method.
        /// Return the candidate locations; these will be drawn as red
        /// lines in the simulator. There should be a point that matches
        /// where the probe is looking. Type "where" to see where the probe
        /// is looking.
        /// </summary>
        public CelestialPoint[] Locate(CelestialPoint[] observations)
        {
            /// This default implementation just returns the observations.
            /// If you run this then you can see how the points are reported
            /// from the local reference frame of the probe.

            return observations;
        }

        /// <summary>
        /// This is a debugging method. Type "dlocate" from the simulator
        /// to call this method. Along with the observations, it provides you
        /// with the true coordinates of the observations in the sources array.
        /// The looking point is the true direction of the probe, which you
        /// must calculate from the observations.
        /// </summary>
        public CelestialPoint[] Locate(CelestialPoint[] observations, 
                                       CelestialPoint[] sources, 
                                       CelestialPoint looking)
        {
            //// This implementation returns a random points from ICRF2
            var r = new Random();

            //// Code contracts should give a warning about this array access.
            //// Because it doesn't know about Random.Next().
            var p = ICRF2.Points[r.Next(0, ICRF2.Points.Length)];

            return new CelestialPoint[] { p };
        }

        public Navigator()
        {
        }
    }
}
